import { Directive, ElementRef, HostListener, NgModule } from '@angular/core';
import { DecimalPipe } from '@angular/common';
import { NgControl } from '@angular/forms';

class InputPriceDirective {
    constructor(_DecimalPipe, _el, ngControl) {
        this._DecimalPipe = _DecimalPipe;
        this._el = _el;
        this.ngControl = ngControl;
        this.isEleFocus = false;
        _el.nativeElement.style.textAlign = 'right';
        _el.nativeElement.style.paddingRight = '4px';
    }
    ngOnInit() {
        // This for initial: init form before pathchValue
        if (this.ngControl && this.ngControl.control) {
            this.ngControl.control.valueChanges.subscribe(e => {
                if (!this.isEleFocus) {
                    let map = this._el.nativeElement.value;
                    if (typeof map === 'string') {
                        map = +(this._el.nativeElement.value.replace(/,/g, ''));
                    }
                    if (map) {
                        this._el.nativeElement.value = (this._DecimalPipe.transform(map, '1.2-2'));
                    }
                }
            });
        }
        // This for initial: pathchValue before init form
        if (this.ngControl && this.ngControl.value) {
            let map = this.ngControl.value;
            if (typeof map === 'string') {
                map = +(this._el.nativeElement.value.replace(/,/g, ''));
            }
            if (map) {
                this._el.nativeElement.value = (this._DecimalPipe.transform(map, '1.2-2'));
            }
        }
    }
    onInput(value) {
        if (this._el.nativeElement.value != null) {
            const re = /[^0-9.]/g;
            re.test(this._el.nativeElement.value);
            // this.ctrl.setValue(this._el.nativeElement.value.replace(re, ''));
            this._el.nativeElement.value = this._el.nativeElement.value.replace(re, '');
        }
    }
    onFocus() {
        this.isEleFocus = true;
        if (this._el.nativeElement.value != null) {
            if (typeof this._el.nativeElement.value === 'string') {
                this._el.nativeElement.value = this._el.nativeElement.value.replace(/,/g, '');
            }
            if (typeof this._el.nativeElement.value === 'number') {
                this._el.nativeElement.value = this._DecimalPipe.transform(this._el.nativeElement.value, '1.2-2');
            }
        }
    }
    onBlur() {
        this.isEleFocus = false;
        if (this._el.nativeElement.value) {
            if (typeof this._el.nativeElement.value === 'string') {
                this.ngControl.control.setValue(+(this._el.nativeElement.value.replace(/,/g, '')));
                // this._el.nativeElement.value = +(this._el.nativeElement.value.replace(/,/g, ''));
                this._el.nativeElement.value = (this._DecimalPipe.transform(+(this._el.nativeElement.value.replace(/,/g, '')), '1.2-2'));
            }
            else {
                this._el.nativeElement.value = (this._DecimalPipe.transform(this._el.nativeElement.value, '1.2-2'));
            }
        }
    }
}
InputPriceDirective.decorators = [
    { type: Directive, args: [{
                selector: '[inputPrice]'
            },] }
];
InputPriceDirective.ctorParameters = () => [
    { type: DecimalPipe },
    { type: ElementRef },
    { type: NgControl }
];
InputPriceDirective.propDecorators = {
    onInput: [{ type: HostListener, args: ["input", ["$event.target.value"],] }],
    onFocus: [{ type: HostListener, args: ["focus",] }],
    onBlur: [{ type: HostListener, args: ["blur",] }]
};

class InputPriceLibModule {
}
InputPriceLibModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    // InputPriceLibComponent,
                    InputPriceDirective
                ],
                imports: [],
                exports: [
                    // InputPriceLibComponent,
                    InputPriceDirective
                ],
                providers: [
                    DecimalPipe
                ]
            },] }
];

/*
 * Public API Surface of input-price-lib
 */

/**
 * Generated bundle index. Do not edit.
 */

export { InputPriceDirective, InputPriceLibModule };
//# sourceMappingURL=ng-input-price-format.js.map
